@@ -24,9 +24,7 @@
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
-#include <assert.h>
 #include <stdio.h>
-#include <gcrypt.h>
 
 #include "opencdk.h"
 #include "main.h"
